This is the policy product for edrndmcc.appserver.  It specifies and
orchestrates the additional products needed to turn a Plone site into the
Early Detection Research Network's Data Management and Coordinating Center's
Application Server.
